function c = propag(s, b, a, n)
% PROPAG Propagacija ili uslovna dilatacija
% c = propag(s, b, a, n)
% s - seed
% b - strukturni element
% a - maska
% n - broj iteracija, ako se zada Inf operacija se izvrsava dok se rezultujuca slika mijenja

c = s;
i = 1;
done = n == 0;

while(~done)
   lastc = c;
   c = and(dilate(c, b), a);
   done = ((i >= n) | isequal(lastc, c));
   i = i + 1;
end
